@@ -126,7 +126,7 @@ eSRTB_ab <-
                   upper=list(shape1=Inf,shape2=Inf,a=min(X),b=Inf))
   
   est.par.se <- try(sqrt(diag(solve(attributes(est.par)$nll.hessian))),silent=TRUE)
-  if(class(est.par.se) == "try-error") {
+  if(inherits(est.par.se, "try-error")) {
     est.par.se <- rep(NA, length(est.par))
   } 
 } 
